@@ -1,7 +1,8 @@
 use strict;
 use warnings;
 package App::Pastebin::Create;
-
+use Getopt::Long;
+use WWW::Pastebin::PastebinCom::Create;
 #ABSTRACT: Create and upload paste to pastebin (DOCUMENTATION IN DEVELOPMENT)
 # FILE HOLDER/THIS IS COMMAND LINE APP, executable name is pastebin-create
 # type pastebin -h for usage
